You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tez.apache.org by hi...@apache.org on 2015/02/19 19:55:07 UTC

tez git commit: TEZ-1990. Tez UI: DAG details page shows Nan for end time when a DAG is running. (Sreenath Somarajapuram via hitesh)

Repository: tez
Updated Branches:
  refs/heads/master 31b145d74 -> 49f76ad90


TEZ-1990. Tez UI: DAG details page shows Nan for end time when a DAG is running. (Sreenath Somarajapuram via hitesh)


Project: http://git-wip-us.apache.org/repos/asf/tez/repo
Commit: http://git-wip-us.apache.org/repos/asf/tez/commit/49f76ad9
Tree: http://git-wip-us.apache.org/repos/asf/tez/tree/49f76ad9
Diff: http://git-wip-us.apache.org/repos/asf/tez/diff/49f76ad9

Branch: refs/heads/master
Commit: 49f76ad9041ef1efaa4fc4a86106dfa55790ad29
Parents: 31b145d
Author: Hitesh Shah <hi...@apache.org>
Authored: Thu Feb 19 10:54:35 2015 -0800
Committer: Hitesh Shah <hi...@apache.org>
Committed: Thu Feb 19 10:54:35 2015 -0800

----------------------------------------------------------------------
 CHANGES.txt                                                    | 1 +
 tez-ui/src/main/webapp/app/scripts/helpers/handlebarHelpers.js | 4 ++--
 2 files changed, 3 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/tez/blob/49f76ad9/CHANGES.txt
----------------------------------------------------------------------
diff --git a/CHANGES.txt b/CHANGES.txt
index e9d4ea7..77b0985 100644
--- a/CHANGES.txt
+++ b/CHANGES.txt
@@ -70,6 +70,7 @@ Release 0.6.1: Unreleased
 INCOMPATIBLE CHANGES
 
 ALL CHANGES:
+  TEZ-1990. Tez UI: DAG details page shows Nan for end time when a DAG is running.
   TEZ-2116. Tez UI: dags page filter does not work if more than one filter is specified.
   TEZ-2106. TEZ UI: Display data load time, and add a refresh button for items that can be refreshed.
   TEZ-2114. Tez UI: task/task attempt status is not available when its running.

http://git-wip-us.apache.org/repos/asf/tez/blob/49f76ad9/tez-ui/src/main/webapp/app/scripts/helpers/handlebarHelpers.js
----------------------------------------------------------------------
diff --git a/tez-ui/src/main/webapp/app/scripts/helpers/handlebarHelpers.js b/tez-ui/src/main/webapp/app/scripts/helpers/handlebarHelpers.js
index f9a2a56..0cd6b9d 100644
--- a/tez-ui/src/main/webapp/app/scripts/helpers/handlebarHelpers.js
+++ b/tez-ui/src/main/webapp/app/scripts/helpers/handlebarHelpers.js
@@ -17,14 +17,14 @@
  */
 
 /**
    * formats the given unix timestamp. returns NaN if its not a number.
    *
    * @param {number} unixtimestamp 
    * @returns {string} 
    * @method formatUnixTimestamp
    */
 Em.Handlebars.helper('formatUnixTimestamp', function(timestamp) {
-	if (!App.Helpers.number.isValidInt(timestamp)) return 'NaN';
+	if (!App.Helpers.number.isValidInt(timestamp)) return 'Not Available';
 	if (timestamp > 0) {
 		return App.Helpers.date.dateFormat(timestamp);
 	}
@@ -17,14 +17,14 @@
 
 /**
-   * formats the given unix timestamp. returns NaN if its not a number.
+   * formats the given unix timestamp. returns Not Available if its not a number.
    *
    * @param {number} unixtimestamp 